==> compmec_shape-0.1.0.tar.gz: compmec_shape-0.1.0/README.md <==
[![Documentation Status][docs-img]][docs-url]
[![Build Status][build-img]][build-url]
[![Lint with Black][lintblack-img]][lintblack-url]
[![Code Coverage][coverage-img]][coverage-url]

[![PyPI Version][pypi-img]][pypi-url]
[![Python Versions][pyversions-img]][pyversions-url]
[![License: MIT][license-img]][license-url]


A python package for bidimensional geometric shapes manipulation.


### Installation:

This library is available in [PyPI][pypi-url]. To install it

```
$ pip install compmec-shape
```

For more details, refer to the [documentation][docs-url].

### Documentation

The documentation can be found at [compmec-shape.readthedocs.io][docs-url]


### Contribute

Please use the [Issues][issues-url] or refer to the email ```compmecgit@gmail.com```

<!-- Badges: -->

[lintblack-img]: https://github.com/compmec/shape-properties/actions/workflows/black.yaml/badge.svg
[lintblack-url]: https://github.com/compmec/shape-properties/actions/workflows/black.yaml
[docs-img]: https://readthedocs.org/projects/compmec-shape/badge/?version=latest
[docs-url]: https://compmec-shape.readthedocs.io/en/latest/?badge=latest
[pypi-img]: https://img.shields.io/pypi/v/compmec-shape
[pypi-url]: https://pypi.org/project/compmec-shape/
[build-img]: https://github.com/compmec/shape-properties/actions/workflows/build.yaml/badge.svg
[build-url]: https://github.com/compmec/shape-properties/actions/workflows/build.yaml
[coverage-img]: https://codecov.io/gh/compmec/shape-properties/branch/main/graph/badge.svg?token=vfGMPe9W3I
[coverage-url]: https://codecov.io/gh/compmec/shape-properties
[pyversions-img]: https://img.shields.io/pypi/pyversions/compmec-shape.svg?style=flat-square
[pyversions-url]: https://pypi.org/project/compmec-shape/
[license-img]: https://img.shields.io/pypi/l/ansicolortags.svg
[license-url]: https://github.com/compmec/shape-properties/blob/main/LICENSE.md
[pypi-url]: https://pypi.org/project/compmec-shape/
[issues-url]: https://github.com/compmec/shape-properties/issues

==> compmec_shape-1.0.0.tar.gz: compmec_shape-1.0.0/README.md <==
[![Documentation Status][docs-img]][docs-url]
[![Build Status][build-img]][build-url]
[![Lint with Black][lintblack-img]][lintblack-url]
[![Code Coverage][coverage-img]][coverage-url]

[![PyPI Version][pypi-img]][pypi-url]
[![Python Versions][pyversions-img]][pyversions-url]
[![License: MIT][license-img]][license-url]


A python package for bidimensional geometric shapes manipulation.


### Installation:

This library is available in [PyPI][pypi-url]. To install it

```
$ pip install compmec-shape
```

For more details, refer to the [documentation][docs-url].

### Documentation

The documentation can be found at [compmec-shape.readthedocs.io][docs-url]


### Contribute

Please use the [Issues][issues-url] or refer to the email ```compmecgit@gmail.com```

<!-- Badges: -->

[lintblack-img]: https://github.com/compmec/shape/actions/workflows/black.yaml/badge.svg
[lintblack-url]: https://github.com/compmec/shape/actions/workflows/black.yaml
[docs-img]: https://readthedocs.org/projects/compmec-shape/badge/?version=latest
[docs-url]: https://compmec-shape.readthedocs.io/en/latest/?badge=latest
[pypi-img]: https://img.shields.io/pypi/v/compmec-shape
[pypi-url]: https://pypi.org/project/compmec-shape/
[build-img]: https://github.com/compmec/shape/actions/workflows/build.yaml/badge.svg
[build-url]: https://github.com/compmec/shape/actions/workflows/build.yaml
[coverage-img]: https://codecov.io/gh/compmec/shape/branch/main/graph/badge.svg?token=vfGMPe9W3I
[coverage-url]: https://codecov.io/gh/compmec/shape
[pyversions-img]: https://img.shields.io/pypi/pyversions/compmec-shape.svg?style=flat-square
[pyversions-url]: https://pypi.org/project/compmec-shape/
[license-img]: https://img.shields.io/pypi/l/ansicolortags.svg
[license-url]: https://github.com/compmec/shape/blob/main/LICENSE.md
[pypi-url]: https://pypi.org/project/compmec-shape/
[issues-url]: https://github.com/compmec/shape/issues
